@@ -1,10 +1,11 @@
 """
-$Id: module_autorejoin.py 331 2012-11-13 10:18:18Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/modules/module_autorejoin.py $
+$Id$
+$HeadURL$
 """
+from __future__ import unicode_literals, print_function, division
 
 # rejoin after 1 minute
-delay = 60
+delay = 61
 
 from twisted.internet import reactor
 
