@@ -1,7 +1,8 @@
 """
-$Id: module_bmi.py 331 2012-11-13 10:18:18Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/modules/module_bmi.py $
+$Id$
+$HeadURL$
 """
+from __future__ import unicode_literals, print_function, division
 
 
 def calc_bmi(height, weight):
@@ -28,9 +29,9 @@ def print_bmi(bmi):
 
 
 def command_bmi(bot, user, channel, args):
-    """Calculates your body mass index. Usage: .bmi height(cm)/weight(kg)"""
+    """Calculates your body mass index. Usage: bmi height(cm)/weight(kg)"""
     data = args.split("/")
     if len(data) != 2:
-        return bot.say(channel, "error with arguments")
+        return bot.say(channel, "Usage: bmi height(cm)/weight(kg)")
     else:
         return bot.say(channel, print_bmi(calc_bmi(int(data[0]), int(data[1]))))
