@@ -1,16 +1,21 @@
 # -*- coding: utf-8 -*-
 
 """
-$Id: module_forecast.py 331 2012-11-13 10:18:18Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/modules/module_forecast.py $
+$Id$
+$HeadURL$
 """
 
+from __future__ import unicode_literals, print_function, division
+import logging
+
+log = logging.getLogger("forecast")
+
 has_pywapi = False
 try:
     import pywapi
     has_pywapi = True
 except:
-    print('Error loading library pywapi. Probably you havent installed it yet.')
+    log.error('Error loading library pywapi. Library not found.')
 
 
 def fahrenheit_to_celcius(f):
@@ -28,10 +33,10 @@ def command_forecast(bot, user, channel, args):
         return
 
     def format_day(day):
-        return (u'%s: %s (%.0f°C/%.0f°C)' % (day['day_of_week'], \
-                          day['condition'], \
-                          fahrenheit_to_celcius(day['low']), \
-                          fahrenheit_to_celcius(day['high'])))
+        return (u'%s: %s (%.0f°C/%.0f°C)' % (day['day_of_week'],
+                            day['condition'],
+                            fahrenheit_to_celcius(day['low']),
+                            fahrenheit_to_celcius(day['high'])))
 
     answerstr = u'%s: ' % (result_dict['forecast_information']['city'])
     answerstr += u", ".join(format_day(day) for day in result_dict['forecasts'])
