@@ -1,15 +1,16 @@
 """
-$Id: module_imdb.py 331 2012-11-13 10:18:18Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/modules/module_imdb.py $
+$Id$
+$HeadURL$
 """
 
+from __future__ import unicode_literals, print_function, division
 has_imdb = False
 
 try:
     from imdb import IMDb
     has_imdb = True
 except:
-    print "Could not find IMDbPY library, please install from http://imdbpy.sourceforge.net/"
+    print("Could not find IMDbPY library, please install from http://imdbpy.sourceforge.net/")
 import re
 
 
