@@ -6,10 +6,11 @@
 @copyright Copyright (c) 2010 Henri Salo
 @licence BSD
 
-$Id: module_rss.py 332 2012-11-13 10:38:14Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/modules/module_rss.py $
+$Id$
+$HeadURL$
 """
 
+from __future__ import unicode_literals, print_function, division
 import sys
 import os
 import re
@@ -236,6 +237,7 @@ def command_rss(bot, user, channel, args):
 
 def shorturl(url):
     try:
+        # TODO: Use requests
         req = urllib2.Request("http://api.bit.ly/v3/shorten?%s" % urllib.urlencode({'longUrl': url, 'login': rssconfig["bitly_login"], 'apiKey': rssconfig["bitly_api_key"], 'format': 'json'}))
         results = json.loads(urllib2.urlopen(req).read())
         #log.debug("Shorturl: %s" % results['id'].encode("UTF-8"))
@@ -432,7 +434,7 @@ def rotator_indexfeeds(bot, delay):
         if (empty_database > 0):
             indexfeeds_callLater = reactor.callLater(delay, rotator_indexfeeds, bot, delay)
     except Exception, e:
-        print e
+        print(e)
 
 
 def rotator_output(bot, delay):
@@ -447,4 +449,4 @@ def rotator_output(bot, delay):
         if (empty_database > 0):
             output_callLater = reactor.callLater(delay, rotator_output, bot, delay)
     except Exception, e:
-        print e
+        print(e)
