@@ -1,8 +1,9 @@
 """
-$Id: module_webchat.py 331 2012-11-13 10:18:18Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/modules/module_webchat.py $
+$Id$
+$HeadURL$
 """
 
+from __future__ import unicode_literals, print_function, division
 import socket
 
 
